@@ -1,18 +1,9 @@
-from typing import (
-    Callable,
-    Coroutine,
-    ForwardRef,
-    Protocol,
-    TypedDict,
-    TypeVar,
-    Union,
-    overload,
-)
+from typing import Coroutine, Optional, Protocol, TypedDict, TypeVar, Union, overload
 
 from typing_extensions import NotRequired
 
 from telebot import callback_data, types
-from telebot.text_matcher import TextMatcher
+from telebot.check_text import CheckText
 from telebot.types.constants import ContentType
 
 UpdateContent = Union[
@@ -46,7 +37,7 @@ FilterValue = Union[
     callback_data.CallbackData,  # callback query handler for a particular CallbackData
     FilterFunc,
     bool,  # to turn on CustomFilters
-    TextMatcher,
+    CheckText,
     None,  # no filter
 ]
 
@@ -67,6 +58,7 @@ class Handler(TypedDict):
     function: HandlerFunction
     filters: dict[str, FilterValue]
     name: NotRequired[str]
+    priority: NotRequired[Optional[int]]
 
 
 ChatId = Union[str, int]
